@@ -35,12 +35,13 @@ def select(array: list):
             print(row_data)
 
         key = kb.read_key()
-        kb.read_key()
+        assert key == kb.read_key()
 
         if key == 'up': row -= 1
         elif key == 'down': row += 1
         elif key == 'enter':
-            for _ in range(row_len+4):
+            input('skipping real key input')
+            for _ in range(row_len+5):
                 sys.stdout.write("\033[F")
                 sys.stdout.write("\033[K")
             return row
